@@ -119,9 +119,9 @@ class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
     def start(self, n):
         self.context["cores"] = self.cores
         if self.mem:
-            lsf_unit = lsf.get_lsf_units()
+            lsf_unit = lsf.get_lsf_units(resource=True)
             mem = utils.convert_mb(float(self.mem) * 1024, lsf_unit)
-            self.context["mem"] = "#BSUB -M %s" % mem
+            self.context["mem"] = '#BSUB -R "rusage[mem=%s]"' % mem
         else:
             self.context["mem"] = ""
         self.context["tag"] = self.tag if self.tag else "bcbio"
@@ -749,7 +749,7 @@ def _is_up(url_file, n):
 
 @contextlib.contextmanager
 def cluster_view(scheduler, queue, num_jobs, cores_per_job=1, profile=None,
-                 start_wait=16, extra_params=None, retries=None):
+                 start_wait=16, extra_params=None, retries=None, direct=False):
     """Provide a view on an ipython cluster for processing.
 
       - scheduler: The type of cluster to start (lsf, sge, pbs, torque).
@@ -801,7 +801,10 @@ def cluster_view(scheduler, queue, num_jobs, cores_per_job=1, profile=None,
             if slept > max_delay:
                 raise IOError("Cluster startup timed out.")
         client = Client(url_file, timeout=60)
-        yield _get_balanced_blocked_view(client, retries)
+        if direct:
+            yield _get_direct_view(client, retries)
+        else:
+            yield _get_balanced_blocked_view(client, retries)
     finally:
         if client:
             client.close()
@@ -817,6 +820,14 @@ def _get_balanced_blocked_view(client, retries):
         view.set_flags(retries=int(retries))
     return view
 
+
+def _get_direct_view(client, retries):
+    view = client[:]
+    view.set_flags(block=True)
+    if retries:
+        view.set_flags(retries=int(retries))
+    return view
+
 def _slurm_is_old():
     return LooseVersion(_slurm_version()) < LooseVersion("2.6")
 
